/*
 * @(#)NavigationButtons.java
 *
 * Copyright (c) 2008 Jeremy Wood. All Rights Reserved.
 *
 * You have a non-exclusive, royalty free, license to use,
 * modify and redistribute this software in source and binary code form,
 * provided that i) this copyright notice and license appear on all copies of
 * the software; and ii) You do not utilize the software in a manner
 * which is disparaging to the original author.
 *
 * This software is provided "AS IS," without a warranty of any kind. ALL
 * EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY
 * IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR
 * NON-INFRINGEMENT, ARE HEREBY EXCLUDED. THE AUTHOR SHALL NOT BE
 * LIABLE FOR ANY DAMAGES SUFFERED AS A RESULT OF USING, MODIFYING
 * OR DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL THE
 * AUTHOR BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT,
 * INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
 * CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF
 * OR INABILITY TO USE SOFTWARE, EVEN IF THE AUTHOR HAS BEEN ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 */
package com.bric.swing;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.RenderingHints;
import java.awt.geom.GeneralPath;
import java.awt.image.BufferedImage;

import javax.swing.ImageIcon;
import javax.swing.JButton;

import com.bric.plaf.SimpleRoundedButtonUI;

/** Static methods to create navigation buttons.
 * It is assumed these buttons will be placed adjacent to each other.
 * 
 */
public class NavigationButtons {
	private static final boolean isMac = System.getProperty("os.name").toLowerCase().indexOf("mac")!=-1;
	
	public static JButton createPrev() {
		JButton b = new JButton(createIcon(false));
		if(isMac) {
			b.putClientProperty("JButton.buttonType", "segmentedTextured");
		} else {
			b.setUI(new SimpleRoundedButtonUI());
		}
		b.putClientProperty("JButton.segmentPosition", "first");
		return b;
	}
	public static JButton createNext() {
		JButton b = new JButton(createIcon(true));
		if(isMac) {
			b.putClientProperty("JButton.buttonType", "segmentedTextured");
		} else {
			b.setUI(new SimpleRoundedButtonUI());
		}
		b.putClientProperty("JButton.segmentPosition", "last");
		return b;
	}
	
	private static ImageIcon createIcon(boolean flip) {
		BufferedImage bi = new BufferedImage(10,10, BufferedImage.TYPE_INT_ARGB);
		Graphics2D g = bi.createGraphics();
		GeneralPath path = new GeneralPath();
		int x = bi.getWidth()/2;
		int y = bi.getHeight()/2;
		if(flip) {
			path.moveTo(x-4,y-4);
			path.lineTo(x+4,y);
			path.lineTo(x-4,y+4);
		} else {
			path.moveTo(x+4,y+4);
			path.lineTo(x-4,y);
			path.lineTo(x+4,y-4);
		}
		g.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
		float dy = .6f;
		g.translate(0,dy);
		g.setColor(Color.white);
		g.fill(path);
		g.translate(0,-dy);
		g.setColor(Color.darkGray);
		g.fill(path);
		g.dispose();
		return new ImageIcon(bi);
	}
}
